@@ -76,16 +76,3 @@ class WeChat:
                 return result['media_id']
         except Exception as err:
             raise Exception("upload media error", err)
-
-
-if __name__ == '__main__':
-    # 企业ID
-    corpid = 'ww06fa03084e27ff22'
-    # 仲达（测试）
-    agentid = 1000116
-    secret = 'uwYEfV7eyDL1y3IzkD_RvksxiA5UBvmJzWNP4ze8vjU'
-
-    zd_test = WeChat(corpid, secret, agentid)
-    media_id = zd_test.upload_media_get_media_id('image', "/Users/zfang/Downloads/", "执兽证备案.png")
-    # '{"errcode":0,"errmsg":"ok","type":"image","media_id":"3N-M1QV6R9hqIGo2SK5oVgvRPZGpoNwSMGCscU3VespI91GKzD-0gBfBW7ucD4Wz3","created_at":"1667360848"}'
-    print(media_id)
